@@ -1,11 +1,9 @@
-from typing import Dict, Union, Any
-
 from tonclient.bindings.lib import tc_create_context, tc_destroy_context, \
     tc_read_string, tc_destroy_string
 from tonclient.bindings.types import TCClientContext, TCSyncResponseData
 from tonclient.boc import TonBoc
 from tonclient.debot import TonDebot
-from tonclient.decorators import Response
+from tonclient.decorators import result_as
 from tonclient.errors import TonException
 from tonclient.module import TonModule
 from tonclient.crypto import TonCrypto
@@ -13,86 +11,48 @@ from tonclient.net import TonNet
 from tonclient.abi import TonAbi
 from tonclient.processing import TonProcessing
 from tonclient.tvm import TonTvm
-from tonclient.types import DEFAULT_MNEMONIC_DICTIONARY, \
-    DEFAULT_MNEMONIC_WORD_COUNT, DEFAULT_HDKEY_DERIVATION_PATH, \
-    AppRequestResult
+from tonclient.types import ClientError, ClientConfig, ResultOfVersion, \
+    ResultOfGetApiReference, ResultOfBuildInfo, ParamsOfResolveAppRequest
 from tonclient.utils import TonUtils
 
 DEVNET_BASE_URL = 'net.ton.dev'
 MAINNET_BASE_URL = 'main.ton.dev'
 
-CLIENT_DEFAULT_SETUP = {
-    'network': {
-        'server_address': 'http://localhost',
-        'network_retries_count': 5,
-        'message_retries_count': 5,
-        'message_processing_timeout': 40000,
-        'wait_for_timeout': 40000,
-        'out_of_sync_threshold': 15000,
-        'access_key': ''
-    },
-    'crypto': {
-        'mnemonic_dictionary': DEFAULT_MNEMONIC_DICTIONARY,
-        'mnemonic_word_count': DEFAULT_MNEMONIC_WORD_COUNT,
-        'hdkey_derivation_path': DEFAULT_HDKEY_DERIVATION_PATH
-    },
-    'abi': {
-        'workchain': 0,
-        'message_expiration_timeout': 40000,
-        'message_expiration_timeout_grow_factor': 1.5
-    }
-}
-
 
 class TonClientBase(TonModule):
-    @Response.version
-    def version(self) -> str:
+    @result_as(classname=ResultOfVersion)
+    def version(self) -> ResultOfVersion:
         """ Returns Core Library version """
         return self.request(method='client.version')
 
-    @Response.get_api_reference
-    def get_api_reference(self) -> Dict:
+    @result_as(classname=ResultOfGetApiReference)
+    def get_api_reference(self) -> ResultOfGetApiReference:
         """ Returns Core Library API reference """
         return self.request(method='client.get_api_reference')
 
-    def build_info(self) -> Dict[str, Any]:
+    @result_as(classname=ResultOfBuildInfo)
+    def build_info(self) -> ResultOfBuildInfo:
         return self.request(method='client.build_info')
 
-    def resolve_app_request(
-            self, app_request_id: int,
-            result: Union[AppRequestResult.Ok, AppRequestResult.Error]):
-        """
-        Resolves application request processing result
-        :param app_request_id: Request ID received from SDK
-        :param result: Result of request processing
-        :return:
-        """
+    def resolve_app_request(self, params: ParamsOfResolveAppRequest):
+        """ Resolves application request processing result """
         return self.request(
-            method='client.resolve_app_request', app_request_id=app_request_id,
-            result=result.dict)
+            method='client.resolve_app_request', **params.dict)
 
 
 class TonClient(object):
     """ Main client class to create object of """
     def __init__(
-            self, network: Dict[str, Union[str, int]] = None,
-            crypto: Dict[str, str] = None,
-            abi: Dict[str, Union[int, float]] = None,
-            is_core_async: bool = True, is_async: bool = False):
+            self, config: ClientConfig, is_core_async: bool = True,
+            is_async: bool = False):
         """
-        :param network: Client core network config
-        :param crypto: Client core crypto config
-        :param abi: Client core abi config
+        :param config: ClientConfig object
         :param is_core_async: Use sync or async core requests
         :param is_async: Client mode
         """
         super(TonClient, self).__init__()
 
-        self._ctx = self.create_context(config={
-            'network': {**CLIENT_DEFAULT_SETUP['network'], **(network or {})},
-            'crypto': {**CLIENT_DEFAULT_SETUP['crypto'], **(crypto or {})},
-            'abi': {**CLIENT_DEFAULT_SETUP['abi'], **(abi or {})}
-        })
+        self._ctx = self.create_context(config=config)
         self._is_core_async = is_core_async
         self._is_async = is_async
 
@@ -135,15 +95,15 @@ class TonClient(object):
         return self.base.resolve_app_request
 
     @staticmethod
-    def create_context(config: Dict[str, Dict[str, Union[str, int, float]]]):
-        response_ptr = tc_create_context(config=config)
+    def create_context(config: ClientConfig):
+        response_ptr = tc_create_context(config=config.dict)
         response = TCSyncResponseData(tc_read_string(string=response_ptr))
         is_success, result, error = (
             response.is_success, response.result, response.error)
         tc_destroy_string(response_ptr)
 
         if not is_success:
-            raise TonException(error=error)
+            raise TonException(error=ClientError(**error))
 
         return TCClientContext(result)
 
